@@ -7,7 +7,6 @@
 #pragma once
 
 #include <gio/gio.h>
-#include <glib-object.h>
 
 #include "fwupd-device.h"
 #include "fwupd-enums.h"
@@ -40,17 +39,27 @@ struct _FwupdClientClass {
 /**
  * FwupdClientDownloadFlags:
  * @FWUPD_CLIENT_DOWNLOAD_FLAG_NONE:		No flags set
- * @FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_IPFS:	Only use IPFS when downloading URIs
+ * @FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_P2P:	Only use peer-to-peer when downloading URIs
  *
  * The options to use for downloading.
  **/
 typedef enum {
-	FWUPD_CLIENT_DOWNLOAD_FLAG_NONE = 0,	       /* Since: 1.4.5 */
-	FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_IPFS = 1 << 0, /* Since: 1.5.6 */
+	FWUPD_CLIENT_DOWNLOAD_FLAG_NONE = 0,	      /* Since: 1.4.5 */
+	FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_P2P = 1 << 0, /* Since: 1.9.4 */
 	/*< private >*/
 	FWUPD_CLIENT_DOWNLOAD_FLAG_LAST
 } FwupdClientDownloadFlags;
 
+/**
+ * FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_IPFS:
+ *
+ * For API compatibility:
+ *
+ * Since: 1.5.6
+ * Deprecated: 1.9.4
+ **/
+#define FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_IPFS FWUPD_CLIENT_DOWNLOAD_FLAG_ONLY_P2P
+
 /**
  * FwupdClientUploadFlags:
  * @FWUPD_CLIENT_UPLOAD_FLAG_NONE:		No flags set
@@ -83,6 +92,15 @@ fwupd_client_connect_finish(FwupdClient *self,
 gboolean
 fwupd_client_disconnect(FwupdClient *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
+fwupd_client_quit_async(FwupdClient *self,
+			GCancellable *cancellable,
+			GAsyncReadyCallback callback,
+			gpointer callback_data);
+gboolean
+fwupd_client_quit_finish(FwupdClient *self,
+			 GAsyncResult *res,
+			 GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
 fwupd_client_get_devices_async(FwupdClient *self,
 			       GCancellable *cancellable,
 			       GAsyncReadyCallback callback,
@@ -221,6 +239,23 @@ fwupd_client_get_results_finish(FwupdClient *self,
 				GAsyncResult *res,
 				GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
+fwupd_client_modify_bios_setting_async(FwupdClient *self,
+				       GHashTable *settings,
+				       GCancellable *cancellable,
+				       GAsyncReadyCallback callback,
+				       gpointer callback_data);
+gboolean
+fwupd_client_modify_bios_setting_finish(FwupdClient *self, GAsyncResult *res, GError **error);
+void
+fwupd_client_get_bios_settings_async(FwupdClient *self,
+				     GCancellable *cancellable,
+				     GAsyncReadyCallback callback,
+				     gpointer callback_data);
+GPtrArray *
+fwupd_client_get_bios_settings_finish(FwupdClient *self,
+				      GAsyncResult *res,
+				      GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
 fwupd_client_get_host_security_attrs_async(FwupdClient *self,
 					   GCancellable *cancellable,
 					   GAsyncReadyCallback callback,
@@ -322,7 +357,15 @@ fwupd_client_refresh_remote_async(FwupdClient *self,
 				  FwupdRemote *remote,
 				  GCancellable *cancellable,
 				  GAsyncReadyCallback callback,
-				  gpointer callback_data);
+				  gpointer callback_data)
+    G_DEPRECATED_FOR(fwupd_client_refresh_remote2_async);
+void
+fwupd_client_refresh_remote2_async(FwupdClient *self,
+				   FwupdRemote *remote,
+				   FwupdClientDownloadFlags download_flags,
+				   GCancellable *cancellable,
+				   GAsyncReadyCallback callback,
+				   gpointer callback_data);
 gboolean
 fwupd_client_refresh_remote_finish(FwupdClient *self,
 				   GAsyncResult *res,
@@ -360,6 +403,43 @@ GHashTable *
 fwupd_client_get_report_metadata_finish(FwupdClient *self,
 					GAsyncResult *res,
 					GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_inhibit_async(FwupdClient *self,
+			   const gchar *reason,
+			   GCancellable *cancellable,
+			   GAsyncReadyCallback callback,
+			   gpointer callback_data);
+gchar *
+fwupd_client_inhibit_finish(FwupdClient *self,
+			    GAsyncResult *res,
+			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_uninhibit_async(FwupdClient *self,
+			     const gchar *inhibit_id,
+			     GCancellable *cancellable,
+			     GAsyncReadyCallback callback,
+			     gpointer callback_data);
+gboolean
+fwupd_client_uninhibit_finish(FwupdClient *self,
+			      GAsyncResult *res,
+			      GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_emulation_load_async(FwupdClient *self,
+				  GBytes *data,
+				  GCancellable *cancellable,
+				  GAsyncReadyCallback callback,
+				  gpointer callback_data);
+gboolean
+fwupd_client_emulation_load_finish(FwupdClient *self, GAsyncResult *res, GError **error);
+void
+fwupd_client_emulation_save_async(FwupdClient *self,
+				  GCancellable *cancellable,
+				  GAsyncReadyCallback callback,
+				  gpointer callback_data);
+GBytes *
+fwupd_client_emulation_save_finish(FwupdClient *self,
+				   GAsyncResult *res,
+				   GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 FwupdStatus
 fwupd_client_get_status(FwupdClient *self);
@@ -373,9 +453,13 @@ guint
 fwupd_client_get_percentage(FwupdClient *self);
 const gchar *
 fwupd_client_get_daemon_version(FwupdClient *self);
+void
+fwupd_client_set_daemon_version(FwupdClient *self, const gchar *daemon_version);
 const gchar *
 fwupd_client_get_host_bkc(FwupdClient *self);
 const gchar *
+fwupd_client_get_host_vendor(FwupdClient *self);
+const gchar *
 fwupd_client_get_host_product(FwupdClient *self);
 const gchar *
 fwupd_client_get_host_machine_id(FwupdClient *self);
